from setuptools import find_packages, setup

setup(
    name='ABC_Kuba_1210',
    version='0.1.0',
    author='Kuba',
    author_email='kuba.polakiewicz2002@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    description='Kuba projekt testowy'
)